/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * <BR><BR>
 *
 * Author: John Thompson, Greenstone Digital Library, University of Waikato
 *
 * <BR><BR>
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * <BR><BR>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * <BR><BR>
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * <BR><BR>
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */
package org.greenstone.gatherer.msm;

import java.io.*;
import javax.swing.filechooser.*;
import org.greenstone.gatherer.Dictionary;
import org.greenstone.gatherer.Gatherer;

/** A custom <strong>FileFilter</strong> for the file choosers. */
final public class MDSFileFilter
    extends javax.swing.filechooser.FileFilter {
    private String description = null;

    /** Constructor.
     * @see org.greenstone.gatherer.Dictionary
     */
    public MDSFileFilter() {
	description = Dictionary.get("MSMPrompt.File_Filter_Description");
    }

    /** Override this method to return <i>true</i> only if the file extension is .mds.
     * @param f A possible mds <strong>File</strong>.
     * @return <i>true</i> if we should show this file, <i>false</i> otherwise.
     */
    public boolean accept(File f) {
	String file_name = f.getName();
	file_name = file_name.toLowerCase();
	if(file_name.endsWith(".mds") || file_name.indexOf(".") == -1) {
	    return true;
	}
	return false;
    }

    /** Retrieve the description for this filter.
     * @return The description as a <strong>String</strong>.
     */
    public String getDescription() {
	return description;
    }
}
